

module (..., package.seeall)

--[[ 
    Module for managing and player sound. 
    TODO: Further functionality for stopping, pause, volume control, music shuffle
    needs to be added
]]

effectsEnabled = true
musicEnabled = true

local audioLibrary = {}
local channels = {}


--- Plays the sound effect with the given name. Takes into account 'effectsEnabled'.
--  Please note that effects are fully loaded into memory before playback. For large
--  infrequent audio use 'playMusic'.
-- @param soundName The the name of the effect to play.
-- @return The channel that the audio was played on or zero if the audio wasn't played.

function playEffect (soundName)
    
    if effectsEnabled then
        
        if audioLibrary[soundName] == nil then
            audioLibrary[soundName] = audio.loadSound(soundName)
        end
        
        return audio.play(audioLibrary[soundName]) 
        
    end
    
    return 0
    
end

--- Plays the music with the given name. Takes into account 'musicEnabled'.
--  Please note that this function streams the audio file, uses fade in and plays
-- This function play given file on a channel from channels table. 
--  the given audio on an infine loop. 
--  TODO: add more customisable functionality here. 
-- @param musicName The name of the music file to play
-- @return The channel that the audio was played on or zero if the audio wasn't played.
function playMusic (musicName)
    print("play music")
    if musicEnabled then
        
        -- load music 
        if audioLibrary[musicName] == nil then
            audioLibrary[musicName] = audio.loadStream(musicName)
            audio.setVolume(.1)
        end
        -- set a channel in channels table
        channels[musicName] = audio.play(audioLibrary[musicName],{loops = -1, fadein = 2000})
        
        
        return  channels[musicName]
    end
    return 0
end

--- Stops the music with the given name
-- TODO: add more customisable functionality here.
--@param musicName The name of the audio channel that music played on it. 
function stopMusic(musicName)
    
    if musicEnabled then

        return audio.stop(channels[musicName])
   
    end
    return 0
    
end